@@ -3,13 +3,13 @@ import os
 import click
 
 from . import launchable
-
+from ..utils.file_name_pattern import jvm_test_pattern
 
 @click.argument('source_roots', required=True, nargs=-1)
 @launchable.subset
 def subset(client, source_roots):
     def file2test(f: str):
-        if f.endswith('.java') or f.endswith('.scala') or f.endswith('.kt'):
+        if jvm_test_pattern.match(f):
             f = f[:f.rindex('.')]   # remove extension
             # directory -> package name conversion
             cls_name = f.replace(os.path.sep, '.')
